﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Text;
using CnetSDK.Excel.Trial;

namespace CnetSDK.Excel.Trial.Demo
{
    public static class HowToEditExcel
    {
        public static void AddAFormulaToCell()
        {
            // Create a new Excel.
            CSExcel ExcelLibrary = new CSExcel();
            // Create a new sheet.
            CSSheet Sheet1 = ExcelLibrary.CreateSheet();

            // Add 5 rows.
            for (int i = 0; i < 5; i++)
            {
                CSRow Row1 = Sheet1.AddRow(i);
                // Insert 2 numbers in the first and second columns separately.
                for (int j = 0; j < 2; j++)
                {
                    CSCell Cell1 = Row1.AddCell(j);
                    Cell1.InputValue(i * 10 + j);
                }

                // Create a cell.
                CSCell CellFormula = Row1.AddCell(2);
                // Add a formula.Please do not input '='at the beginning of the formula.
                StringBuilder Builder = new StringBuilder();
                Builder.AppendFormat("SUM(A{0}:B{0})", (i + 1).ToString());
                CellFormula.SetFormula(Builder.ToString());
            }

            // Save and show the sheet.
            if (File.Exists("CnetSDKSample.xlsx")) File.Delete("CnetSDKSample.xlsx");
            ExcelLibrary.Save("CnetSDKSample.xlsx");
            Process.Start("CnetSDKSample.xlsx");
        }

        public static void EditExcel()
        {
            // Load an Excel from a local file.
            CSExcel ExcelLibrary = new CSExcel("CnetSDKSample.xlsx");
            // Get a sheet by name.
            CSSheet Sheet1 = ExcelLibrary.GetSheet("Sheet1");

            // Get a row by row ID.
            CSRow Row1 = Sheet1.GetRow(0);
            if (Row1 != null)
            {
                /*If the cell will have the same cell type as original cell,you can
update its value directly.For example, the original cell type is Int
and its value is "000", and you want to change its value to Int "111".*/
                CSCell UpdateCell = Row1.GetCell(0);
                if (UpdateCell != null)
                {
                    UpdateCell.InputValue(111);
                }

                /*If the cell will have a different cell type, you should create a
new cell to replace the original one. For example, the value of
original cell is Int "000", and you want to change it to String value "CnetSDK".*/
                CSCell NewCell = Row1.AddCell(1);
                NewCell.InputValue("CnetSDKExcel-1");
            }

            // Save and show the sheet.
            if (File.Exists("CnetSDKSample.xlsx")) File.Delete("CnetSDKSample.xlsx");
            ExcelLibrary.Save("CnetSDKSample.xlsx");
            Process.Start("CnetSDKSample.xlsx");
        }

        public static void FormatValueOfNumericCell()
        {
            // Create a new Excel.
            CSExcel ExcelLibrary = new CSExcel();
            // Create a new sheet.
            CSSheet Sheet1 = ExcelLibrary.CreateSheet();

            // Create a new row at the first line.
            CSRow Row1 = Sheet1.AddRow(0);
            // Create a numeric cell.
            CSCell NumericCell = Row1.AddCell(0);
            NumericCell.InputValue(111, "##0");
            /*cellNumeric.SetValue(111.22, "##0.##");
            cellNumeric.SetValue(111.222, "##0.##");
            cellNumeric.SetValue(111.222, "000");*/

            // Save and show the sheet.
            if (File.Exists("CnetSDKSample.xlsx")) File.Delete("CnetSDKSample.xlsx");
            ExcelLibrary.Save("CnetSDKSample.xlsx");
            Process.Start("CnetSDKSample.xlsx");
        }

        public static void FormatValueOfDateTimeCell()
        {
            // Create a new Excel.
            CSExcel ExcelLibrary = new CSExcel();
            // Create a new sheet.
            CSSheet Sheet1 = ExcelLibrary.CreateSheet();

            // Create a new row at the first line.
            CSRow Row1 = Sheet1.AddRow(0);
            // Create a date time cell.
            CSCell DataTimeCell = Row1.AddCell(0);
            DataTimeCell.InputValue(DateTime.Now, "dd-MM-yyyy HH:mm:ss");
            /*cellDateTime.SetValue(DateTime.Now, "MM/dd/yyyy");
              cellDateTime.SetValue(DateTime.Now, "HH:mm");*/

            // Save and show the sheet.
            if (File.Exists("CnetSDKSample.xlsx")) File.Delete("CnetSDKSample.xlsx");
            ExcelLibrary.Save("CnetSDKSample.xlsx");
            Process.Start("CnetSDKSample.xlsx");
        }


        public static void EditExcelFromStream()
        {
            CSExcel ExcelLibrary = null;

            using (FileStream ExcelStream = new FileStream("CnetSDKSample.xlsx", FileMode.Open, FileAccess.Read))
            {
                ExcelLibrary = new CSExcel(ExcelStream);
            }

            CSSheet Sheet1 = ExcelLibrary.GetSheet("Sheet1");

            CSRow Row1 = Sheet1.GetRow(0);
            if (Row1 != null)
            {
                CSCell cell0 = Row1.GetCell(0);
                if (cell0 != null)
                {
                    cell0.InputValue(789);
                }

                CSCell cell3 = Row1.AddCell(3);
                cell3.InputValue("CnetSDKExcel");
            }

            if (File.Exists("CnetSDKSample.xlsx")) File.Delete("CnetSDKSample.xlsx");
            using (FileStream fs = new FileStream("CnetSDKSample.xlsx", FileMode.Open, FileAccess.Write))
            {
                ExcelLibrary.Save(fs);
            }
        }
    }
}