﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.SqlClient;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Text;
using CnetSDK.Excel.Trial;

namespace CnetSDK.Excel.Trial.Demo
{
    public static class HowToImportData
    {
        public static void ImportDataTableToSheet()
        {
            string FileName = "CnetSDKSample.xlsx";
            // Get a datatable with specified data.
            DataTable Datatable = CreateDataTable();

            // Create a new Excel.
            CSExcel ExcelLibrary = new CSExcel();
            // Import data from datatable to sheet.
            ExcelLibrary.ImportDataFromDataTableToSheet(Datatable);

            // Save and show the sheet.
            if (File.Exists(FileName)) File.Delete(FileName);
            ExcelLibrary.Save(FileName);
            Process.Start(FileName);
        }

        public static void ImportDataSetToSheets()
        {
            string FileName = "CnetSDKSample.xlsx";
            // Get a dataset with specified data.
            DataSet Dataset = CreateDataSet();

            // Create a new Excel.
            CSExcel ExcelLibrary = new CSExcel();
            // Import each datatable in dataset
            foreach (DataTable Datatable in Dataset.Tables)
            {
                ExcelLibrary.ImportDataFromDataTableToSheet(Datatable);
            }

            // Save and show the sheet.
            if (File.Exists(FileName)) File.Delete(FileName);
            ExcelLibrary.Save(FileName);
            Process.Start(FileName);
        }

        private static DataSet CreateDataSet()
        {
            DataTable Datatable1 = CreateDataTable();
            DataTable Datatable2 = CreateDataTable2();

            DataSet dataset = new DataSet();
            dataset.Tables.Add(Datatable1);
            dataset.Tables.Add(Datatable2);

            return dataset;
        }

        private static DataTable CreateDataTable()
        {
            DataTable Datatable = new DataTable("CnetSDKSample1");
            Datatable.Columns.Add("Name", typeof(string));
            Datatable.Columns.Add("Number", typeof(int));

            for (int i = 0; i < 1680; i++)
            {
                DataRow dr = Datatable.NewRow();
                dr[0] = "name-" + i.ToString();
                dr[1] = i;
                Datatable.Rows.Add(dr);
            }

            return Datatable;
        }

        private static DataTable CreateDataTable2()
        {
            DataTable Datatable = new DataTable("CnetSDKSample2");
            Datatable.Columns.Add("Id", typeof(int));
            Datatable.Columns.Add("Version", typeof(string));

            for (int i = 0; i < 100; i++)
            {
                DataRow dr = Datatable.NewRow();
                dr[0] = i;
                dr[1] = "version-" + i.ToString();
                Datatable.Rows.Add(dr);
            }

            return Datatable;
        }

        public static void ImportSQLTableToSheet1()
        {
            // Export data from SQL database.
            DataTable Datatable = GetTableFromSQLDatabase();
            string FileName = "CnetSDKSample.xlsx";

            // Create a new Excel.
            CSExcel ExcelLibrary = new CSExcel();
            // Import datatable from SQL to sheet.
            ExcelLibrary.ImportDataFromDataTableToSheet(Datatable);

            // Save and show the sheet.
            if (File.Exists(FileName)) File.Delete(FileName);
            ExcelLibrary.Save(FileName);
            Process.Start(FileName);
        }

        private static DataTable GetTableFromSQLDatabase()
        {
            DataTable Datatable = null;
            string connString = @"Data Source = .; Initial Catalog = your database name; Integrated Security = True";
            string query = "select * from table";

            SqlConnection conn = new SqlConnection(connString);
            SqlCommand cmd = new SqlCommand(query, conn);
            conn.Open();

            // Create data adapter.
            SqlDataAdapter DataAdapter = new SqlDataAdapter(cmd);
            // Query your database and return the result to your datatable.
            DataAdapter.Fill(Datatable);
            conn.Close();
            DataAdapter.Dispose();

            return Datatable;
        }


        public static void ImportDataTableToSheet2()
        {
            string FileName = "CnetSDKSample.xlsx";
            DataTable Datatable = CreateDataTable();

            CSExcel ExcelLibrary = new CSExcel();
            CSSheet Sheet1 = null;
            if (Datatable.TableName != null && Datatable.TableName != "")
            {
                Sheet1 = ExcelLibrary.CreateSheet("CnetSDK");
            }
            else
            {
                Sheet1 = ExcelLibrary.CreateSheet();
            }

            int rowId = 0;
            if (Datatable.Columns.Count > 0)
            {
                int columnId = 0;
                CSRow row = Sheet1.AddRow(rowId);
                foreach (DataColumn dc in Datatable.Columns)
                {
                    CSCell Cell1 = row.AddCell(columnId);
                    Cell1.InputValue(dc.ColumnName);
                    columnId++;
                }
            }
            rowId++;

            foreach (DataRow dr in Datatable.Rows)
            {
                if (rowId % 2 == 0)
                {
                    continue;
                }
                CSRow Row1 = Sheet1.AddRow(rowId);
                int columnId = 0;
                foreach (DataColumn dc in Datatable.Columns)
                {
                    CSCell Cell2 = null;
                    object cellValue = dr[columnId];

                    switch (dc.DataType.ToString())
                    {
                        case "System.String":
                            if (cellValue != DBNull.Value)
                            {
                                Cell2 = Row1.AddCell(columnId);
                                Cell2.InputValue(Convert.ToString(cellValue));
                            }
                            break;
                        case "System.Int32":
                            if (cellValue != DBNull.Value)
                            {
                                Cell2 = Row1.AddCell(columnId);
                                Cell2.InputValue(Convert.ToInt32(cellValue));
                            }
                            break;
                        default:
                            break;
                    }
                    columnId++;
                }
                rowId++;
            }

            if (File.Exists(FileName)) File.Delete(FileName);
            ExcelLibrary.Save(FileName);
        }
    }
}